| Title: | A Notepad Inside RStudio |
|---|---|
| Description: | A project aware notepad inside RStudio, for taking quick project-related notes without distractions. RStudio addin. |
| Authors: | Valerio Gherardi [aut, cre] (ORCID: <https://orcid.org/0000-0002-8215-3013>) |
| Maintainer: | Valerio Gherardi <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.2.1 |
| Built: | 2026-05-26 10:22:43 UTC |
| Source: | https://github.com/vgherard/scribblr |
scribblr note editorOpens the scribblr note editor in a new window.
scribble(note = NULL)scribble(note = NULL)
note |
either |
scribblr integrates a minimalist note editor within RStudio,
useful for taking quick project-related notes without distractions.
scribblr notes are RStudio project aware: each project has associated
its own notes, which can be accessed by calling scribble(), and are
stored into the project's root directory. Using scribble() without
any active project will take the R home directory as root.
Calling scribble() with the default note = NULL gives access to
the main project notes. Otherwise, note must be a string specifying a
valid filename.
scribblr notes and settings for the active project are stored in the
".scribblr" directory, under the project's root. If this, or the note
specified by note, do not exist, the user will be prompted for
permission to create the required files/directories.
Notes are autosaved when the editor is closed; until that moment, the R session will remain busy.
scribble() can also be called (and, in particular, associated a
custom keystroke) via the RStudio Addin "Open scribblr note editor".
returns NULL, invisibly. Called for side-effects.
Valerio Gherardi
## Not run: scribble() ## End(Not run)## Not run: scribble() ## End(Not run)
scribblr noteDelete a scribblr note.
scribblr_delete(note)scribblr_delete(note)
note |
a length one character (not NA). Note to be deleted. |
returns NULL, invisibly. Used for side-effects.
Valerio Gherardi
## Not run: scribblr_delete("todo") ## End(Not run)## Not run: scribblr_delete("todo") ## End(Not run)
scribblr notesList all scribblr notes.
scribblr_list()scribblr_list()
a character vector.
Valerio Gherardi
## Not run: scribblr_list("todo") ## End(Not run)## Not run: scribblr_list("todo") ## End(Not run)